const { sendMessage } = require('./utils');

function isPlayerOnline(task) {
    const playerStatus = task["PlayerStatus"];
    if (!playerStatus || !playerStatus["Enabled"]) return true;

    const onlinePlayers = mc.getOnlinePlayers();
    const includeFakePlayers = playerStatus["FakePlayer"];
    const whitelist = playerStatus["Whitelist"] || [];

    const filteredPlayers = onlinePlayers.filter(player =>
        includeFakePlayers || !player.isSimulatedPlayer()
    );
    const filteredNames = filteredPlayers.map(p => p.realName);

    const nonWhitelistPlayers = filteredNames.filter(name => {
        try {
            return !whitelist.some(pattern => new RegExp(pattern).test(name));
        } catch (err) {
            sendMessage(null, `白名单正则匹配错误: ${err.message}`, 'error');
            return true;
        }
    });

    if (nonWhitelistPlayers.length === 0) {
        sendMessage(null, `没有其他玩家在线，任务将不执行。`, 'debug');
        return false;
    }

    const hasWhitelistPlayer = filteredNames.some(name => {
        try {
            return whitelist.some(pattern => new RegExp(pattern).test(name));
        } catch (err) {
            sendMessage(null, `白名单正则匹配错误: ${err.message}`, 'error');
            return false;
        }
    });

    if (hasWhitelistPlayer) {
        sendMessage(null, `白名单玩家在线，任务将被阻止执行。`, 'debug');
        return false;
    }

    sendMessage(null, `任务可以正常执行，符合条件的玩家在线。`, 'debug');
    return true;
}

module.exports = { isPlayerOnline };
