const { sendMessage } = require('./utils');
const { isPlayerOnline } = require('./playerChecker');

// 定义任务计数器
const taskCounters = {};

// 执行 Minecraft 服务器命令
async function executeServerCommand(command) {
    sendMessage(null, `正在执行服务器命令: ${command}`, 'info');
    mc.runcmdEx(command);
    /*
    const result =  mc.runcmdEx(command);
    if (result.success) {
        sendMessage(null, `服务器命令执行成功`, 'info');
    } else {
        sendMessage(null, `服务器命令执行失败`, 'error');
    }
    */
}




// 执行系统命令
async function executeSystemCommand(command) {
    sendMessage(null, `正在执行系统命令: ${command}`, 'info');
    const { exec } = require('child_process');
    const util = require('util');
    const execAsync = util.promisify(exec);

    try {
        // 为系统命令设置超时时间，防止卡死
        const { stdout, stderr } = await execAsync(command, { timeout: 60000 }); // 超时设置为 60 秒
        if (stderr) {
            sendMessage(null, `系统命令错误输出: ${stderr}`, 'warn');
        }
        sendMessage(null, `系统命令输出: ${stdout}`, 'info');
    } catch (error) {
        // 捕获错误信息并输出
        if (error.killed) {
            sendMessage(null, `系统命令被强制终止 (超时)。`, 'error');
        } else {
            sendMessage(null, `系统命令执行失败: ${error.message}`, 'error');
        }
    }
}

async function executeTask(taskName, task) {
    sendMessage(null, `正在检查任务: ${taskName}`, 'debug');

    if (!taskCounters[taskName]) {
        taskCounters[taskName] = 0;
    }

    if (!isPlayerOnline(task)) {
        if (taskCounters[taskName] === 0) {
            sendMessage(null, `任务 ${taskName} 未检测到玩家在线，首次执行任务指令。`, 'debug');
            await handleTaskExecution(task);
            taskCounters[taskName] = 1;
        } else {
            sendMessage(null, `任务 ${taskName} 未执行：连续检测到玩家不在线。`, 'debug');
        }
        return;
    }

    sendMessage(null, `任务 ${taskName} 检测到玩家在线，重置计数器。`, 'debug');
    taskCounters[taskName] = 0;

    await handleTaskExecution(task);
}

async function handleTaskExecution(task) {
    const mode = task["Mode"];
    if (mode["Type"] === "ServerCommand") {
        await executeServerCommand(mode["Command"]);
    } else if (mode["Type"] === "SystemCommand") {
        await executeSystemCommand(mode["Command"]);
    } else {
        sendMessage(null, `未知任务类型: ${mode["Type"]}`, 'warn');
    }
}

module.exports = { executeTask };
